@@ -16,8 +16,10 @@
 #include "ntp_net.h"
 #include "nts.h"
 
-extern int32_t ntp_random (void);
-extern uint64_t ntp_random64 (void);
+/* common place to check/crash on unlikely error return */
+void ntp_RAND_bytes(unsigned char *buf, int num);
+void ntp_RAND_priv_bytes(unsigned char *buf, int num);
+
 
 /*
  * Calendar arithmetic - contributed by G. Healton
@@ -348,17 +350,17 @@ struct peer {
 /* Packet Modes
  */
 #define	MODE_UNSPEC	0	/* unspecified (old version) */
-#define	MODE_ACTIVE	1	/* symmetric active mode */
-#define	MODE_PASSIVE	2	/* symmetric passive mode */
+#define	MODE_ACTIVEx	1	/* symmetric active mode */
+#define	MODE_PASSIVEx	2	/* symmetric passive mode */
 #define	MODE_CLIENT	3	/* client mode */
 #define	MODE_SERVER	4	/* server mode */
-#define	MODE_BROADCAST	5	/* broadcast mode */
+#define	MODE_BROADCASTx	5	/* broadcast mode */
 
 /*
  * These can appear in packets
  */
 #define	MODE_CONTROL	6	/* control mode, ntpq*/
-#define	MODE_PRIVATE	7	/* Dead: private mode, was ntpdc */
+#define	MODE_PRIVATEx	7	/* Dead: private mode, was ntpdc */
 /*
  * This is a madeup mode for broadcast client.  No longer used by ntpd.
  */
@@ -565,8 +567,8 @@ struct pkt {
 #define PROTO_FLOOR		17
 #define PROTO_CEILING		18
 /* #define PROTO_COHORT		19 */
-#define PROTO_CALLDELAY		20
-#define PROTO_MINDISP		21
+/* #define PROTO_CALLDELAY	20 */
+#define PROTO_MINDIST		21
 #define PROTO_MAXDIST		22
 #define	PROTO_MAXDISP		23
 #define	PROTO_MAXHOP		24
@@ -611,8 +613,9 @@ struct mon_data {
 	endpt *		lcladr;		/* address on which this arrived */
 	l_fp		first;		/* first time seen */
 	l_fp		last;		/* last time seen */
-	int		leak;		/* leaky bucket accumulator */
 	int		count;		/* total packet count */
+	unsigned int	dropped;	/* packets dropped */
+	float		score;		/* recent packets/second */
 	unsigned short	flags;		/* restrict flags */
 	uint8_t		vn_mode;	/* packet mode & version */
 	sockaddr_u	rmtadr;		/* address of remote host */
@@ -701,6 +704,9 @@ struct restrict_u_tag {
 #define	RES_FLAKE		0x1000	/* flakeway - drop 10% */
 #define	RES_NOMRULIST		0x2000	/* mode 6 mrulist denied */
 
+/* RES_DEFAULT defined in resolv.h */
+#define RES_Default (RES_NOQUERY|RES_LIMITED)
+
 /* pythonize-header: start ignoring */
 
 /*
@@ -726,18 +732,6 @@ struct endpoint {
 	int	type;			/* interval entry/exit */
 };
 
-/*
- * Association matching AM[] return codes
- */
-#define AM_ERR		-1		/* error */
-#define AM_NOMATCH	0		/* no match */
-#define AM_PROCPKT	1		/* server/symmetric packet */
-#define AM_BCST		2		/* broadcast packet */
-#define AM_FXMIT	3		/* client packet */
-#define AM_MANYCAST	4		/* manycast or pool */
-#define AM_NEWPASS	5		/* new passive */
-#define AM_NEWBCL	6		/* new broadcast */
-#define AM_POSSBCL	7		/* discard broadcast */
 
 /* ntpq -c mrulist rows per request limit in ntpd */
 #define MRU_ROW_LIMIT	256
