@@ -63,7 +63,7 @@ def read_append(s, packets, packet, sockaddr):
         if not ntp.packet.Authenticator.have_mac(d):
             if debug:
                 log("no MAC on reply from %s" % packet.hostname)
-        if not credentials.verify_mac(d):
+        if not credentials.verify_mac(d, packet_end=48, mac_begin=48):
             packet.trusted = False
             log("MAC verification on reply from %s failed"
                 % sockaddr[0])
@@ -197,15 +197,15 @@ def report(packet, json):
 
     packet.posixize()
 
-    if time.daylight:
-        tmoffset = time.altzone // 60  # In minutes
-    else:
-        tmoffset = time.timezone // 60  # In minutes
-
     # The server's idea of the time
     t = time.localtime(int(packet.transmit_timestamp))
     ms = int(packet.transmit_timestamp * 1000000) % 1000000
 
+    if t.tm_isdst:
+        tmoffset = -time.altzone // 60  # In minutes
+    else:
+        tmoffset = -time.timezone // 60  # In minutes
+
     # Number of decimal digits of precision indicated by the precision field
     digits = min(6, -int(math.log10(2**packet.precision)))
 
@@ -244,7 +244,7 @@ USAGE:  ntpdig [-<flag> [<val>] | --<name>[{=| }<val>]]...
    -c yes concurrent      Hosts to be queried concurrently
    -d no  debug           Increase debug verbosity
    -D yes set-debug-level Set debug verbosity
-   -g yes gap             Set gap between requests in miliseconds
+   -g yes gap             Set gap between requests in milliseconds
    -j no  json            Use JSON output format
    -l Str logfile         Log to specified logfile
                                  - prohibits the option 'syslog'
