@@ -939,7 +939,7 @@ class TestPylibUtilMethods(unittest.TestCase):
                                         "foo.bar.com", "1.2.3.4")]
             self.assertEqual(cls.summary(ent),
                              "64730 23296      0  400 K 7 2"
-                             "      1    42 1.2.3.4")
+                             "      1        -      -    42 1.2.3.4")
             # Test summary, second options
             mycache._cache = {}
             cls.now = 0x00000000
@@ -952,8 +952,8 @@ class TestPylibUtilMethods(unittest.TestCase):
                                          "foo.bar.com", ("1.2.3.4", 42))]]
             cdns_jig_returns = ["foo.com"]
             self.assertEqual(cls.summary(ent),
-                             "64730 23808   4.00   20 L 7 2     65"
-                             "    42 foo.com")
+                             "64730 23808    256   20 L 7 2     65"
+                             "        -      -    42 foo.com")
             # Test summary, third options
             mycache._cache = {}
             ent.ct = 2
@@ -961,7 +961,7 @@ class TestPylibUtilMethods(unittest.TestCase):
             fakesockmod.gai_error_count = 1
             cdns_jig_returns = ["foobarbaz" * 5]  # 45 chars, will be cropped
             self.assertEqual(cls.summary(ent),
-                             "64730 23808    256    0 . 7 2      2    42"
+                             "64730 23808    256    0 . 7 2      2        -      -    42"
                              " 1.2.3.4 (foobarbazfoobarbazfoobarbazfoob")
             # Test summary, wide
             mycache._cache = {}
@@ -970,7 +970,7 @@ class TestPylibUtilMethods(unittest.TestCase):
             cdns_jig_returns = ["foobarbaz" * 5]  # 45 chars, will be cropped
             self.assertEqual(cls.summary(ent),
                              "64730 23808    256    0 . 7 2      2"
-                             "    42 1.2.3.4 "
+                             "        -      -    42 1.2.3.4 "
                              "(foobarbazfoobarbazfoobarbazfoobarbazfoobarbaz)")
         finally:
             ntp.util.socket = socktemp
