@@ -12,6 +12,8 @@ def options_cmd(ctx, config):
                    default=False, help="Enable debugging code")
     grp.add_option('--enable-debug-gdb', action='store_true',
                    default=False, help="Enable GDB debugging symbols")
+    grp.add_option('--disable-nts', action='store_true',
+                   default=False, help="Disable NTS.")
     grp.add_option('--disable-droproot', action='store_true',
                    default=False, help="Disable dropping root.")
     grp.add_option('--enable-early-droproot', action='store_true',
@@ -81,12 +83,6 @@ def options_cmd(ctx, config):
     grp.add_option('--undefine', type='string', action="callback",
                    callback=callback_flags,
                    help="Force undefinition of symbol.")
-
-    grp = ctx.add_option_group("NTP documentation configure options")
-    grp.add_option('--enable-doc', action='store_true',
-                   default=False, help="Build NTP documentation")
-    grp.add_option('--enable-a2x-xmllint', action='store_true',
+    grp.add_option('--disable-fuzz', action='store_true',
                    default=False,
-                   help="Build NTP documentation with a2x XML lint")
-    grp.add_option('--disable-manpage', action='store_true',
-                   default=False, help="Disable Manpage building.")
+                   help="Disable fuzzing of low bits of time")
